@@ -12,6 +12,8 @@ __version__ = '0.1.3'
 __release__ = 20230221
 __all__ = ['Pack', 'concat']
 
+logging.basicConfig(format='%(levelname)s:%(message)s', level=logging.INFO)
+
 
 def concat(logs, use_simpandas=None):
     if use_simpandas is None:
@@ -235,8 +237,15 @@ class Pack(object, metaclass=Log2FrameType):
             rows = [len(self.data[w][f]) for w in self.data for f in self.data[w]]
             index_names = [self.data[w][f].index_name for w in self.data for f in self.data[w]]
             index_units = [self.data[w][f].index_units for w in self.data for f in self.data[w]]
-            min_index = [min(self.data[w][f].index) for w in self.data for f in self.data[w]]
-            max_index = [max(self.data[w][f].index) for w in self.data for f in self.data[w]]
+            min_index = [min(self.data[w][f].index)
+                         if len(self.data[w][f].index) > 0 
+                         else None
+                         for w in self.data for f in self.data[w]]
+            max_index = [max(self.data[w][f].index)
+                         if len(self.data[w][f].index) > 0
+                         else None
+                         for w in self.data for f in self.data[w]]
+
             self.summary_ = pd.DataFrame(data={'well': wells,
                                                'curves': curves,
                                                'steps': rows,
